@@ -28,7 +28,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.4.2"
+__version__ = "1.4.3"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -48,7 +48,7 @@ from pathlib import Path
 from urllib.parse import urlparse
 
 _LOGGER = logging.getLogger(__title__)
-_SUPPORTED_PIP_STR = ">=9,<=22.2.1"  # Respects requirement in setup.py and latest pip to release date.
+_SUPPORTED_PIP_STR = ">=9,<=22.2.2"  # Respects requirement in setup.py and latest pip to release date.
 
 try:
     from pip import __version__ as pip_version
@@ -453,7 +453,13 @@ def _instantiate_package_finder(pip_session):  # type: (PipSession) -> PackageFi
         selection_prefs = SelectionPreferences(
             allow_yanked=True,
         )
-        search_scope = SearchScope([], [])
+
+        additional_kwargs = {}
+        if Version(pip_version).release >= (22, 3):
+            # New argument in pip 22.3
+            # https://github.com/pypa/pip/commit/5d7a1a68c7feb75136a0fd120de54b85df105bac
+            additional_kwargs["no_index"] = False
+        search_scope = SearchScope([], [], **additional_kwargs)  # type: ignore
 
         try:
             from pip._internal.index.collector import LinkCollector
@@ -803,6 +809,12 @@ def _poetry2pipfile_lock(
                 requirement["ref"] = entry["source"]["reference"]
             elif entry["source"]["type"] == "directory":
                 requirement["path"] = entry["source"]["url"]
+            elif entry["source"]["type"] == "legacy":
+                # Newer poetry marks packages using the old PyPI API as legacy.
+                # If we have only one source, we can ignore it.
+                # Otherwise, configure it explicitly.
+                if len(sources) > 1:
+                    requirement["index"] = entry["source"]["reference"]
             else:
                 raise NotSupportedError(
                     "micropipenv supports Git VCS or directories, got {} instead".format(entry["source"]["type"])
